@@ -14,7 +14,7 @@
  *  limitations under the License.
  *
  * Img0ch.Thread
- * $Id: thread.js 79 2007-01-11 12:25:09Z hikarin $
+ * $Id: thread.js 133 2007-01-25 14:02:41Z hikarin $
  *
  * @require jquery.js
  * @require domLib.js
@@ -34,7 +34,6 @@ Img0ch.Thread = function(option) {
     var rootNode = option.rootNode || "threadRoot";
     var bbsURL   = baseURL + '/'    + bbs + '/';
     var getFrom  = bbsURL  + "dat/" + key + ".dat.utf8";
-    var autolink = /(https?:\/\/[A-Za-z0-9~\/._\?\&=\-%#\+:\;,\@\']+)/g;
 
     if ( gz ) getFrom += ".gz";
     if ( option.reload == false ) {
@@ -56,8 +55,8 @@ Img0ch.Thread = function(option) {
                 return false;
             }
         }
-        isOpera ? $(document).keypress(preventReload)
-                : $(document).keydown(preventReload);
+        isOpera ? jQuery(document).keypress(preventReload)
+                : jQuery(document).keydown(preventReload);
     }
 
     this.baseURL       = baseURL;
@@ -66,14 +65,22 @@ Img0ch.Thread = function(option) {
     this.key           = key;
     this.lastModified  = "Thu, 01 Jan 1970 00:00:00 GMT";
     this.length        = 0;
+    this.imageLink     = new RegExp(
+        "<a[^>]*>(.+/" + bbs + "/img/" + key
+        + "/(\\d+)\\.([\\w\\.]+))</a>", "g" );
+    this.imageLinkTo   = "<a href='$1' rel='imagebox_" + bbs + "_"
+        + key + "' title='$2.$3'><b>[$3]</b></a>";
     this.isGzip        = gz;
     this.lastUpdate    = new Date();
-    this.linkRegex     = autolink;
+    this.linkRegex     = new RegExp(
+        "(https?://[A-Za-z0-9~/._\\?&=\\-%#\\+:;,@']+)", "g" );
     this.linkReplaceTo = "<a href='" + cushion + "$1'>$1</a>";
     this.option        = opt;
-    this.popRegex      = /(<a[^>]*>)?&gt;&gt;([\d\-]+)(<a[^>]*>)?/g;
+    this.popRegex      = new RegExp(
+        "(<a[^>]*>)?(&gt;|&gt;&gt;|＞|＞＞)([\\d\\-]+)(</a[^>]*>)?", "g" );
     this.popReplaceTo  = "<a href='javascript:void(0)' "
-        + "onmouseover='thread.popup(this, event, \"$2\")'>&gt;&gt;$2</a>";
+        + "onmouseover='thread.popup(this, event, \"$3\")'>&gt;&gt;$3</a>";
+    this.renderCB      = option.renderCallback;
     this.requestURL    = getFrom;
     this.res           = [ [ "", "", "", "", "" ] ];
     this.rootNode      = rootNode;
@@ -85,8 +92,8 @@ Img0ch.Thread.prototype = {
         var self = this;
         var oldSubjectValue = this.getSubject();
         var onReadyStateChange = function() {
-            $(document.getElementById("loading")).hide();
-            $(document.getElementById("reloadLinks")).show();
+            jQuery("div#loading").hide();
+            jQuery("div#reloadLinks").show();
             if ( xhr && xhr.readyState == 4 ) {
                 var status = xhr.status;
                 if ( status == 200 ) {
@@ -131,7 +138,8 @@ Img0ch.Thread.prototype = {
                     self.setSubject(oldSubjectValue);
                 }
                 else if ( status == 404 ) {
-                    self.setSubject("datが存在しません。削除されたかURL間違ってますよ。");
+                    self.setSubject(
+                        "datが存在しません。削除されたかURL間違ってますよ。");
                     self.hideForm();
                 }
                 else if ( status == 416 ) {
@@ -154,19 +162,17 @@ Img0ch.Thread.prototype = {
             xhr.open("GET", this.requestURL, true);
             xhr.setRequestHeader(
                 "X-Requested-With",
-                "XMLHttpRequest"
-            );
+                "XMLHttpRequest" );
             xhr.setRequestHeader(
                 "If-Modified-Since",
-                this.getLastModified()
-            );
+                this.getLastModified() );
             var len = this.getLength();
             if ( !this.isGzip && len > 0 ) {
                 var from = "bytes=" + String(len) + "-";
                 xhr.setRequestHeader( "Range", from );
             }
-            $(document.getElementById("reloadLinks")).hide();
-            $(document.getElementById("loading")).show();
+            jQuery("div#reloadLinks").hide();
+            jQuery("div#loading").show();
             this.setSubject("読み込み中...");
             xhr.onreadystatechange = onReadyStateChange;
             xhr.send(null);
@@ -205,8 +211,7 @@ Img0ch.Thread.prototype = {
         return this.res.length;
     },
     "getSubject": function() {
-        return this.res[0][4]
-            || document.getElementById("threadSubject").innerHTML;
+        return this.res[0][4] || jQuery("div#threadSubject").html();
     },
     "flush": function() {
         this.res.length = 0;
@@ -267,7 +272,7 @@ Img0ch.Thread.prototype = {
         var reses = this.res;
         var root  = document.getElementById(this.rootNode);
 
-        if (isReload) $(root).empty();
+        if (isReload) jQuery(root).empty();
         if ( readFirst ) {
             var res = reses[0];
             this.renderRes(root, 1, res);
@@ -287,7 +292,7 @@ Img0ch.Thread.prototype = {
 
         var rf = document.getElementById("readFrom");
         var loop = Math.floor( count / 100 ) + 1;
-        $(rf).empty();
+        jQuery(rf).empty();
         for ( var i = 0; i < loop; i++ ) {
             var from  = ( i * 100 ) + 1;
             var to    = ( i + 1   ) * 100;
@@ -304,12 +309,12 @@ Img0ch.Thread.prototype = {
         this.setSubject(this.getSubject());
         if ( count >= 1000 ) this.hideForm();
 
-        /* for KTHML's DOM exception */
-        try {
-            document.getElementsByTagName("title").item(0).innerHTML = subj;
-        } catch (e) {
-            /* do nothing */
-        }
+        /* for KTHML and Opera's DOM exception */
+        try { jQuery("title").html(subj); } catch (e) { /* do nothing */ }
+
+        var postRenderCallback = this.renderCB;
+        if (postRenderCallback) postRenderCallback();
+
         document.getElementById("threadSize").innerHTML
             = Math.ceil(this.getLength() / 1024) + "KB";
         return;
@@ -340,6 +345,9 @@ Img0ch.Thread.prototype = {
             ).replace(
                 this.linkRegex,
                 this.linkReplaceTo
+            ).replace(
+                this.imageLink,
+                this.imageLinkTo
             );
     },
     "parse": function(range, len) {
@@ -411,17 +419,16 @@ Img0ch.Thread.prototype = {
         document.getElementById("threadSubject").innerHTML = String(subj);
     },
     "hideForm": function() {
-        $(document.getElementById("postform")).hide().parent().append(
-            $(document.getElementById("VERSION")).clone()
-        );
+        jQuery("div#postform").hide().parent().append(
+            jQuery("div#VERSION").clone());
     },
     "setElapsed": function() {
         var diffTime = new Date() - this.lastUpdate;
-        document.getElementById("renderTime").innerHTML = diffTime;
+        jQuery("span#renderTime").html(diffTime);
     },
     "search": function() {
-        var word   = $("form input#quicksearch").val();
-        var type   = this.intval($("select#searchType").val());
+        var word   = jQuery("form input#quicksearch").val();
+        var type   = this.intval(jQuery("select#searchType").val());
         if ( type < 0 || type > 3 ) type = 3;
         if ( word != '' ) {
             var found = 0;
@@ -429,7 +436,7 @@ Img0ch.Thread.prototype = {
             var words = word.split(' ');
             var wlen  = words.length;
             var root  = document.getElementById(this.rootNode);
-            $(root).empty();
+            jQuery(root).empty();
             for ( var i in reses ) {
                 var res     = reses[i];
                 if ( typeof res[3] == "undefined" ) continue;
@@ -452,7 +459,7 @@ Img0ch.Thread.prototype = {
                     this.renderRes(root, resno, result);
                 }
             }
-            $("span#searchResult").hide().html(
+            jQuery("span#searchResult").hide().html(
                  "「" + word + "」の検索結果："
                  + String(found) + "レス発見しました"
             ).show();
@@ -462,7 +469,7 @@ Img0ch.Thread.prototype = {
         var timeout;
         var self       = this;
         var delay      = 1000;
-        var searching  = $("span#searching");
+        var searching  = jQuery("span#searching");
         var onKeyEvent = function () {
             clearTimeout(timeout);
             timeout = setTimeout( function () {
@@ -472,7 +479,7 @@ Img0ch.Thread.prototype = {
             }, delay / 2);
         }
         searching.hide();
-        $("form input#quicksearch").keyup(function(ev) {
+        jQuery("form input#quicksearch").keyup(function(ev) {
             switch(ev.keyCode) {
                 case 9:
                 case 13:
