@@ -14,7 +14,7 @@
  *  limitations under the License.
  *
  * Zeromin
- * $Id: zeromin.js 109 2007-01-20 12:49:14Z hikarin $
+ * $Id: zeromin.js 139 2007-01-28 11:54:38Z hikarin $
  */
 
 function login() {
@@ -145,6 +145,14 @@ var Zeromin = {
         }
         return filterIP;
     },
+    "getFilterHost": function() {
+        var filterHost = this.getInstanceOf("Filter.Host");
+        if ( !filterHost ) {
+            filterHost = new Zeromin.Filter.Host();
+            this.setInstance("Filter.Host", filterHost);
+        }
+        return filterHost;
+    },
     "getFilterNGWord": function() {
         var filterNGWord = this.getInstanceOf("Filter.NGWord");
         if ( !filterNGWord ) {
