@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: BBS.pm 60 2006-12-31 00:29:40Z hikarin $
+# $Id: BBS.pm 122 2007-01-23 13:51:04Z hikarin $
 #
 
 package Img0ch::BBS;
@@ -47,6 +47,8 @@ sub new {
         _url    => join( '/', $iConfig->get('Server'), $dir ),
         _kernel => $iKernel,
         _repos  => $iRepos,
+        _system => $iKernel->get_repos(
+            $iKernel->get_repos_path( "${dir}/system" ) ),
     }, $iClass;
 }
 
@@ -54,6 +56,8 @@ sub get_kernel { $_[0]->{_kernel} }
 
 sub get_common_repos { $_[0]->{_repos} }
 
+sub get_system_repos { $_[0]->{_system} }
+
 sub id { $_[0]->{_id} }
 
 sub bbs { $_[0]->{_dir} }
@@ -135,13 +139,30 @@ none
 
 =item Return Value
 
-$iRepos
+$iReposCommon
 
 =back
 
 共通レポジトリのオブジェクトを返します。
 この関数はバージョンが2.1.x-3.xでのみ使用可能です。
 
+=head2 get_system_repos
+
+=over 4
+
+=item Arguments
+
+none
+
+=item Return Value
+
+$iReposSystem
+
+=back
+
+掲示板内のみ有効なシステムレポジトリのオブジェクトを返します。
+この関数はバージョンが2.1.x-3.xでのみ使用可能です。
+
 =head2 id
 
 =over 4
